==> syncope-2.0.16-source-release.zip: syncope-2.0.16/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/group/Group.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity.group;

import java.util.List;
import org.apache.syncope.core.persistence.api.entity.Any;
import org.apache.syncope.core.persistence.api.entity.AnyType;
import org.apache.syncope.core.persistence.api.entity.anyobject.ADynGroupMembership;
import org.apache.syncope.core.persistence.api.entity.user.UDynGroupMembership;
import org.apache.syncope.core.persistence.api.entity.user.User;

public interface Group extends Any<GPlainAttr> {

    String getName();

    void setName(String name);

    Group getGroupOwner();

    User getUserOwner();

    void setGroupOwner(Group groupOwner);

    void setUserOwner(User userOwner);

    @Override
    boolean add(GPlainAttr attr);

    @Override
    GPlainAttr getPlainAttr(String plainSchemaName);

    @Override
    List<? extends GPlainAttr> getPlainAttrs();

    UDynGroupMembership getUDynMembership();

    void setUDynMembership(UDynGroupMembership uDynMembership);

    boolean add(ADynGroupMembership dynGroupMembership);

    ADynGroupMembership getADynMembership(AnyType anyType);

    List<? extends ADynGroupMembership> getADynMemberships();

    boolean add(TypeExtension typeExtension);

    TypeExtension getTypeExtension(AnyType anyType);

    List<? extends TypeExtension> getTypeExtensions();
}

==> syncope-2.1.5-source-release.zip: syncope-2.1.5/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/group/Group.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity.group;

import java.util.List;
import java.util.Optional;
import org.apache.syncope.core.persistence.api.entity.Any;
import org.apache.syncope.core.persistence.api.entity.AnyType;
import org.apache.syncope.core.persistence.api.entity.anyobject.ADynGroupMembership;
import org.apache.syncope.core.persistence.api.entity.user.UDynGroupMembership;
import org.apache.syncope.core.persistence.api.entity.user.User;

public interface Group extends Any<GPlainAttr> {

    String getName();

    void setName(String name);

    Group getGroupOwner();

    User getUserOwner();

    void setGroupOwner(Group groupOwner);

    void setUserOwner(User userOwner);

    @Override
    boolean add(GPlainAttr attr);

    @Override
    Optional<? extends GPlainAttr> getPlainAttr(String plainSchema);

    @Override
    List<? extends GPlainAttr> getPlainAttrs();

    UDynGroupMembership getUDynMembership();

    void setUDynMembership(UDynGroupMembership uDynMembership);

    boolean add(ADynGroupMembership dynGroupMembership);

    Optional<? extends ADynGroupMembership> getADynMembership(AnyType anyType);

    List<? extends ADynGroupMembership> getADynMemberships();

    boolean add(TypeExtension typeExtension);

    Optional<? extends TypeExtension> getTypeExtension(AnyType anyType);

    List<? extends TypeExtension> getTypeExtensions();
}
